summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/travel.cc
diff options
context:
space:
mode:
authorCharles Otto <ottochar@gmail.com>2009-11-08 22:40:49 -0500
committerCharles Otto <ottochar@gmail.com>2009-11-08 22:40:49 -0500
commit9701b3016d5d0d1fb67185e7abd675a0de0c129a (patch)
tree784d87393b77498a551a18836128c0bf0f14be6a /crawl-ref/source/travel.cc
parent0a3c856d3d36b49a8430fe9468d2f11ae234f9c8 (diff)
downloadcrawl-ref-9701b3016d5d0d1fb67185e7abd675a0de0c129a.tar.gz
crawl-ref-9701b3016d5d0d1fb67185e7abd675a0de0c129a.zip
Rename Feawn
In most places Feawn is now referred to as "Fedhas," its long name (used in the religion screen) is "Fedhas Madash"
Diffstat (limited to 'crawl-ref/source/travel.cc')
-rw-r--r--crawl-ref/source/travel.cc8
1 files changed, 4 insertions, 4 deletions
diff --git a/crawl-ref/source/travel.cc b/crawl-ref/source/travel.cc
index 32d2241173..a3f69c1507 100644
--- a/crawl-ref/source/travel.cc
+++ b/crawl-ref/source/travel.cc
@@ -309,7 +309,7 @@ static bool _is_monster_blocked(const coord_def& c)
return (mons
&& mons->visible_to(&you)
&& mons_is_stationary(mons)
- && !feawn_passthrough(mons)
+ && !fedhas_passthrough(mons)
&& mons_was_seen(mons)
&& !mons_is_unknown_mimic(mons));
}
@@ -390,9 +390,9 @@ static bool _is_safe_move(const coord_def& c)
if (const monsters *mon = monster_at(c))
{
// Stop before wasting energy on plants and fungi,
// unless a worshipping Feawn.
if (you.can_see(mon) && mons_class_flag(mon->type, M_NO_EXP_GAIN)
- && !feawn_passthrough(mon))
+ && !fedhas_passthrough(mon))
return (false);
// If this is any *other* monster, it'll be visible and
@@ -3819,7 +3819,7 @@ bool runrest::run_grids_changed() const
return (true);
monsters * mon = monster_at(you.pos() + pos);
- if (mon && !feawn_passthrough(mon))
+ if (mon && !fedhas_passthrough(mon))
return (true);
for (int i = 0; i < 3; i++)
@@ -390,9 +390,9 @@ static bool _is_safe_move(const coord_def& c)
{
// Stop before wasting energy on plants and fungi,
- // unless a worshipping Feawn.
+ // unless a worshipping Fedhas.
if (you.can_see(mon) && mons_class_flag(mon->type, M_NO_EXP_GAIN)